@@ -1,19 +1,22 @@
+from .modules import populate_all
 from .private import private
 from .public import public
 
 
-__version__ = '5.1'
+__version__ = '6.0.1'
 
 
 # mypy does not understand that __all__ gets populated at runtime via the
 # public() call below, so be explicit.
 __all__ = [
+    'populate_all',
     'private',
     'public',
 ]
 
 
 public(
+    populate_all=populate_all,
     private=private,
     public=public,
 )
